@@ -26,14 +26,29 @@ type builder struct {
 	configSource         toml.Loader
 	configVersion        int
 	useLegacyConfig      bool
-	path                 string
+	topLevelConfigPath   string
 	runtimeType          string
 	containerAnnotations []string
+
+	containerToHostPathMap map[string]string
 }
 
 // Option defines a function that can be used to configure the config builder
 type Option func(*builder)
 
+// WithContainerPathAsHostPath maps a given container path to a host path.
+func WithContainerPathAsHostPath(containerPath string, hostPath string) Option {
+	return func(b *builder) {
+		if containerPath == "" || hostPath == "" || containerPath == hostPath {
+			return
+		}
+		if b.containerToHostPathMap == nil {
+			b.containerToHostPathMap = make(map[string]string)
+		}
+		b.containerToHostPathMap[containerPath] = hostPath
+	}
+}
+
 // WithLogger sets the logger for the config builder
 func WithLogger(logger logger.Interface) Option {
 	return func(b *builder) {
@@ -41,10 +56,10 @@ func WithLogger(logger logger.Interface) Option {
 	}
 }
 
-// WithPath sets the path for the config builder
-func WithPath(path string) Option {
+// WithTopLevelConfigPath sets the path for the top-level containerd config.
+func WithTopLevelConfigPath(path string) Option {
 	return func(b *builder) {
-		b.path = path
+		b.topLevelConfigPath = path
 	}
 }
 
