@@ -22,9 +22,10 @@ import (
 )
 
 type builder struct {
-	logger       logger.Interface
-	configSource toml.Loader
-	path         string
+	logger             logger.Interface
+	configSource       toml.Loader
+	configDestination  toml.Loader
+	topLevelConfigPath string
 }
 
 // Option defines a function that can be used to configure the config builder
@@ -37,10 +38,10 @@ func WithLogger(logger logger.Interface) Option {
 	}
 }
 
-// WithPath sets the path for the config builder
-func WithPath(path string) Option {
+// WithTopLevelConfigPath sets the path for the top-level containerd config.
+func WithTopLevelConfigPath(path string) Option {
 	return func(b *builder) {
-		b.path = path
+		b.topLevelConfigPath = path
 	}
 }
 
@@ -50,3 +51,10 @@ func WithConfigSource(configSource toml.Loader) Option {
 		b.configSource = configSource
 	}
 }
+
+// WithConfigDestination sets the TOML destination for the config.
+func WithConfigDestination(configDestination toml.Loader) Option {
+	return func(b *builder) {
+		b.configDestination = configDestination
+	}
+}
